@@ -3,11 +3,14 @@ Boto3 ServiceResource or Resource collection.
 """
 from typing import Set
 
+from mypy_boto3_builder.enums.service_module_name import ServiceModuleName
 from mypy_boto3_builder.import_helpers.import_string import ImportString
 from mypy_boto3_builder.service_name import ServiceName
 from mypy_boto3_builder.structures.class_record import ClassRecord
 from mypy_boto3_builder.type_annotations.external_import import ExternalImport
 from mypy_boto3_builder.type_annotations.fake_annotation import FakeAnnotation
+from mypy_boto3_builder.type_annotations.internal_import import InternalImport
+from mypy_boto3_builder.type_annotations.type_subscript import TypeSubscript
 
 
 class Collection(ClassRecord):
@@ -28,9 +31,18 @@ class Collection(ClassRecord):
             name=name,
             use_alias=True,
             bases=[
-                ExternalImport(
-                    source=ImportString("boto3", "resources", "collection"),
-                    name="ResourceCollection",
+                TypeSubscript(
+                    ExternalImport(
+                        source=ImportString("boto3", "resources", "collection"),
+                        name="ResourceCollection",
+                    ),
+                    [
+                        InternalImport(
+                            object_class_name,
+                            service_name=service_name,
+                            module_name=ServiceModuleName.service_resource,
+                        ),
+                    ],
                 )
             ],
         )
@@ -42,10 +54,16 @@ class Collection(ClassRecord):
 
     @property
     def boto3_doc_link(self) -> str:
+        """
+        Link to boto3 docs.
+        """
         return self.service_name.get_boto3_doc_link(self.parent_name, self.attribute_name)
 
     @property
     def docstring(self) -> str:
+        """
+        Class docstring.
+        """
         doc_link = self.service_name.get_doc_link(
             "service_resource",
             self.name,
@@ -58,6 +76,9 @@ class Collection(ClassRecord):
         )
 
     def get_types(self) -> Set[FakeAnnotation]:
+        """
+        Extract type annotations.
+        """
         types = super().get_types()
         types.update(self.type_annotation.get_types())
         return types
